@@ -31,7 +31,6 @@
 #include <netinet/ether.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
-#include <sys/auxv.h>
 #include <sys/statfs.h>
 #include <sys/types.h>
 #include <sys/utsname.h>
@@ -332,8 +331,8 @@ void xtables_announce_chain(const char *name)
 
 void xtables_init(void)
 {
-	/* xtables cannot be used with setuid/setcap in a safe way. */
-	if (getuid() != geteuid() || getauxval(AT_SECURE))
+	/* xtables cannot be used with setuid in a safe way. */
+	if (getuid() != geteuid())
 		_exit(111);
 
 	xtables_libdir = getenv("XTABLES_LIBDIR");
@@ -1747,7 +1746,8 @@ void xtables_ipparse_multiple(const char *name, struct in_addr **addrpp,
                               struct in_addr **maskpp, unsigned int *naddrs)
 {
 	struct in_addr *addrp;
-	char buf[256], *p, *next;
+	char buf[256], *p;
+	const char *next;
 	unsigned int len, i, j, n, count = 1;
 	const char *loop = name;
 
@@ -2046,7 +2046,8 @@ xtables_ip6parse_multiple(const char *name, struct in6_addr **addrpp,
 {
 	static const struct in6_addr zero_addr;
 	struct in6_addr *addrp;
-	char buf[256], *p, *next;
+	char buf[256], *p;
+	const char *next;
 	unsigned int len, i, j, n, count = 1;
 	const char *loop = name;
 
